{
  description = "My NixOS desktop and server configs";

  inputs = {

    # NixOS official package source, using the nixos-23.11 branch here
    nixpkgs-stable.url = "github:NixOS/nixpkgs/nixos-24.05";
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    nixos-hardware.url = "github:nixos/nixos-hardware";

    # Declarative dotfile management
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    # Declarative partitioning and formatting
    disko = {
      url = "github:nix-community/disko";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    stylix.url = "github:danth/stylix";

    nixvim = {
      url = "github:nix-community/nixvim";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    zen = {
      url = "github:MarceColl/zen-browser-flake";
      inputs.nixpkgs.follows = "nixpkgs";
    };

#    # Secrets management. See ./docs/secretsmgmt.md
#    sops-nix = {
#      url = "github:mic92/sops-nix";
#      inputs.nixpkgs.follows = "nixpkgs";
#    };

  };

  outputs = { nixpkgs, nixpkgs-stable, ... }@attrs: 
  let
      lib = nixpkgs.lib;
      pkgs = import nixpkgs { system = "x86_64-linux"; config = { allowUnfree = true; }; };
      pkgs-stable = import nixpkgs-stable { system = "x86_64-linux"; config = { allowUnfree = true; }; };
  in
  {
    nixosConfigurations = {

      Lenni = let
        system = "x86_64-linux";
      in
      lib.nixosSystem {

        specialArgs = {
          hostname = "Lenni";
          type = "desktop";
          inherit pkgs;
          inherit pkgs-stable;
	  inherit attrs;
          inherit system;
        };

        modules = [
          attrs.home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
            }
          attrs.disko.nixosModules.disko
          attrs.stylix.nixosModules.stylix
          attrs.nixvim.nixosModules.nixvim
          attrs.nixos-hardware.nixosModules.framework-12th-gen-intel
          ./hosts
          ./users/willifan
        ];

      };

      Puenktchen = let
        system = "x86_64-linux";
      in
      lib.nixosSystem {

        specialArgs = {
          hostname = "Puenktchen";
          type = "desktop";
          inherit pkgs;
          inherit pkgs-stable;
          inherit system;
        };

        modules = [
          attrs.home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
            }
          attrs.disko.nixosModules.disko
          attrs.stylix.nixosModules.stylix
          attrs.nixvim.nixosModules.nixvim
          attrs.nixos-hardware.nixosModules.common-cpu-amd
          attrs.nixos-hardware.nixosModules.common-cpu-amd-pstate
          attrs.nixos-hardware.nixosModules.common-cpu-amd-zenpower
          attrs.nixos-hardware.nixosModules.common-gpu-amd
          ./hosts
          ./users/willifan
        ];

      };

      Anton = let
        system = "x86_64-linux";
      in
      lib.nixosSystem {

        specialArgs = {
          hostname = "Anton";
          type = "server";
          inherit pkgs;
          inherit pkgs-stable;
          inherit system;
        };

        modules = [
          attrs.home-manager.nixosModules.home-manager
            {
              home-manager.useGlobalPkgs = true;
              home-manager.useUserPackages = true;
            }
          attrs.disko.nixosModules.disko
          attrs.stylix.nixosModules.stylix
          attrs.nixvim.nixosModules.nixvim
          attrs.nixos-hardware.nixosModules.common-cpu-amd
          attrs.nixos-hardware.nixosModules.common-cpu-amd-pstate
          attrs.nixos-hardware.nixosModules.common-cpu-amd-zenpower
          ./hosts
          ./users/willifan
        ];
        
      };

    };
  };
}
